==> libgwenhywfar_4.0.3.orig.tar.gz: gwenhywfar-4.0.3/src/os/inetaddr_l.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Tue Oct 02 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

/**
 * @file src/os/inetaddr.h
 * @short This file contains the internet address handling module
 */

#ifndef GWEN_INETADDR_L_H
#define GWEN_INETADDR_L_H

#include <gwenhywfar/inetaddr.h>


/**
 * Initialize this module.
 */
int GWEN_InetAddr_ModuleInit();

/**
 * De-Initialize this module.
 */
int GWEN_InetAddr_ModuleFini();


#endif /* GWEN_INETADDR_L_H */

==> libgwenhywfar_5.14.1.orig.tar.gz: gwenhywfar-5.14.1/src/os/inetaddr_l.h <==
/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Tue Oct 02 2002
    copyright   : (C) 2002 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

/**
 * @file src/os/inetaddr.h
 * @short This file contains the internet address handling module
 */

#ifndef GWEN_INETADDR_L_H
#define GWEN_INETADDR_L_H

#include <gwenhywfar/inetaddr.h>


/**
 * Initialize this module.
 */
int GWEN_InetAddr_ModuleInit(void);

/**
 * De-Initialize this module.
 */
int GWEN_InetAddr_ModuleFini(void);


#endif /* GWEN_INETADDR_L_H */
